translate.convert.ical2po

Package translate :: Package convert :: Module ical2po |
[hide private]
[frames] | no frames]

# Source Code for Module translate.convert.ical2po

      1  #!/usr/bin/env python
      2  # -*- coding: utf-8 -*-
      3  #
      4  # Copyright 2007 Zuza Software Foundation
      5  #
      6  # This file is part of translate.
      7  #
      8  # translate is free software; you can redistribute it and/or modify
      9  # it under the terms of the GNU General Public License as published by
     10  # the Free Software Foundation; either version 2 of the License, or
     11  # (at your option) any later version.
     12  #
     13  # translate is distributed in the hope that it will be useful,
     14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
     15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     16  # GNU General Public License for more details.
     17  #
     18  # You should have received a copy of the GNU General Public License
     19  # along with translate; if not, write to the Free Software
     20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     21
     22  """convert iCal files to Gettext PO localization files"""
     23
     24  import sys
     25  from translate.storage import po
     26  from translate.storage import ical
     27
     28 -class ical2po:
     29      """convert a iCal file to a .po file for handling the translation..."""
     30 -    def convert_store(self, input_store, duplicatestyle="msgctxt"):
     31          """converts a iCal file to a .po file..."""
     32          output_store = po.pofile()
     33          output_header = output_store.makeheader(charset="UTF-8", encoding="8bit")
     34          output_header.addnote("extracted from %s" % input_store.filename, "developer")
     35          output_store.addunit(output_header)
     36          for input_unit in input_store.units:
     37              output_unit = self.convert_unit(input_unit, "developer")
     38              if output_unit is not None:
     39                  output_store.addunit(output_unit)
     40          output_store.removeduplicates(duplicatestyle)
     41          return output_store
     42
     43 -    def merge_store(self, template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt"):
     44          """converts two iCal files to a .po file..."""
     45          output_store = po.pofile()
     46          output_header = output_store.makeheader(charset="UTF-8", encoding="8bit")
     47          output_header.addnote("extracted from %s, %s" % (template_store.filename, input_store.filename), "developer")
     48          output_store.addunit(output_header)
     49          input_store.makeindex()
     50          for template_unit in template_store.units:
     51              origpo = self.convert_unit(template_unit, "developer")
     52              # try and find a translation of the same name...
     53              template_unit_name = "".join(template_unit.getlocations())
     54              if template_unit_name in input_store.locationindex:
     55                  translatedini = input_store.locationindex[template_unit_name]
     56                  translatedpo = self.convert_unit(translatedini, "translator")
     57              else:
     58                  translatedpo = None
     59              # if we have a valid po unit, get the translation and add it...
     60              if origpo is not None:
     61                  if translatedpo is not None and not blankmsgstr:
     62                      origpo.target = translatedpo.source
     63                  output_store.addunit(origpo)
     64              elif translatedpo is not None:
     65                  print >> sys.stderr, "error converting original iCal definition %s" % origini.name
     66          output_store.removeduplicates(duplicatestyle)
     67          return output_store
     68
     69 -    def convert_unit(self, input_unit, commenttype):
     70          """Converts a .ini unit to a .po unit. Returns None if empty
     71          or not for translation."""
     72          if input_unit is None:
     73              return None
     74          # escape unicode
     75          output_unit = po.pounit(encoding="UTF-8")
     76          output_unit.addlocation("".join(input_unit.getlocations()))
     77          output_unit.addnote(input_unit.getnotes("developer"), "developer")
     78          output_unit.source = input_unit.source
     79          output_unit.target = ""
     80          return output_unit
     81
     82 -def convertical(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt"):
     83      """Reads in L{input_file} using iCal, converts using L{ical2po}, writes to L{output_file}"""
     84      input_store = ical.icalfile(input_file)
     85      convertor = ical2po()
     86      if template_file is None:
     87          output_store = convertor.convert_store(input_store, duplicatestyle=duplicatestyle)
     88      else:
     89          template_store = ical.icalfile(template_file)
     90          output_store = convertor.merge_store(template_store, input_store, blankmsgstr=pot, duplicatestyle=duplicatestyle)
     91      if output_store.isempty():
     92          return 0
     93      output_file.write(str(output_store))
     94      return 1
     95
     96 -def main(argv=None):
     97      from translate.convert import convert
     98      formats = {"ics": ("po", convertical), ("ics", "ics"): ("po", convertical)}
     99      parser = convert.ConvertOptionParser(formats, usetemplates=True, usepots=True, description=__doc__)
    100      parser.add_duplicates_option()
    101      parser.passthrough.append("pot")
    102      parser.run(argv)
    103
    104  if __name__ == '__main__':
    105      main()
    106